@@ -1,3 +1,6 @@
+#' @include periods.r
+NULL
+
 #' Get/set days component of a date-time.
 #'
 #' Date-time must be a POSIXct, POSIXlt, Date, chron, yearmon, yearqtr, zoo, 
@@ -90,8 +93,13 @@ mday.default <- function(x)
 "yday<-" <- function(x, value)
   x <- x + days(value - yday(x))
 
-"wday<-" <- function(x, value)
+"wday<-" <- function(x, value){
+  if (!is.numeric(value)) {
+  	value <- pmatch(tolower(value), c("sunday", "monday", "tuesday", 
+  		"wednesday", "thursday", "friday", "saturday"))
+  }
   x <- x + days(value - wday(x))
+}
 
 "day<-" <- "mday<-" <- function(x, value)
   x <- x + days(value - mday(x))
\ No newline at end of file
