@@ -33,8 +33,8 @@
 #' tz(x) <- "America/New_York"
 #' x
 #' Sys.setenv(TZ = "GMT")
-#' x
-#' tz(x)
+#' now()
+#' tz(now())
 #' Sys.unsetenv("TZ")
 tz <- function (x) 
   UseMethod("tz")
@@ -47,7 +47,7 @@ tz.default <- function(x) {
 }
 
 tz.zoo <- function(x){
-  tzs <- attr(as.POSIXlt(index(x)), "tzone")
+  tzs <- attr(as.POSIXlt(zoo::index(x)), "tzone")
   tzs[1]
 }
 
